@@ -7,8 +7,8 @@ import click
 from scapy.packet import Packet, Raw
 from scapy.sendrecv import sniff
 
-BPLIST_MAGIC = b'bplist'
-PLIST_MAGIC = b'<plist'
+BPLIST_MAGIC = b"bplist"
+PLIST_MAGIC = b"<plist"
 
 
 class PcapSniffer:
@@ -20,13 +20,13 @@ class PcapSniffer:
 
         if BPLIST_MAGIC in packet:
             try:
-                plist = plistlib.loads(packet[packet.find(BPLIST_MAGIC):])
+                plist = plistlib.loads(packet[packet.find(BPLIST_MAGIC) :])
                 self.report(plist)
             except plistlib.InvalidFileException:
                 pass
         if PLIST_MAGIC in packet:
             try:
-                plist = plistlib.loads(packet[packet.find(PLIST_MAGIC):])
+                plist = plistlib.loads(packet[packet.find(PLIST_MAGIC) :])
                 self.report(plist)
             except xml.parsers.expat.ExpatError:
                 pass
@@ -35,37 +35,37 @@ class PcapSniffer:
         try:
             print(plist)
             if self.file is not None:
-                self.file.write('---\n')
+                self.file.write("---\n")
                 self.file.write(pprint.pformat(plist))
-                self.file.write('\n---\n')
+                self.file.write("\n---\n")
         except ValueError:
-            print('failed to print plist')
+            print("failed to print plist")
 
 
 @click.group()
 def cli():
-    """ Parse RemoteXPC traffic """
+    """Parse RemoteXPC traffic"""
     pass
 
 
 @cli.command()
-@click.argument('pcap', type=click.Path(exists=True, file_okay=True, dir_okay=False))
-@click.option('-o', '--out', type=click.File('wt'))
+@click.argument("pcap", type=click.Path(exists=True, file_okay=True, dir_okay=False))
+@click.option("-o", "--out", type=click.File("wt"))
 def offline(pcap: str, out: IO):
-    """ Parse plists traffic from a .pcap file """
+    """Parse plists traffic from a .pcap file"""
     sniffer = PcapSniffer(out)
     for p in sniff(offline=pcap):
         sniffer.process_packet(p)
 
 
 @cli.command()
-@click.argument('iface')
-@click.option('-o', '--out', type=click.File('wt'))
+@click.argument("iface")
+@click.option("-o", "--out", type=click.File("wt"))
 def live(iface: str, out: IO):
-    """ Parse plists live from a given network interface """
+    """Parse plists live from a given network interface"""
     sniffer = PcapSniffer(out)
     sniff(iface=iface, prn=sniffer.process_packet)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli()
