@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 import logging
 import time
+from typing import Optional
 
 from pymobiledevice3.lockdown import LockdownClient
 from pymobiledevice3.lockdown_service_provider import LockdownServiceProvider
@@ -8,10 +9,11 @@ from pymobiledevice3.lockdown_service_provider import LockdownServiceProvider
 
 class HeartbeatService:
     """
-    Use to keep an active connection with lockdowd
+    Use to keep an active connection with lockdownd
     """
-    SERVICE_NAME = 'com.apple.mobile.heartbeat'
-    RSD_SERVICE_NAME = 'com.apple.mobile.heartbeat.shim.remote'
+
+    SERVICE_NAME = "com.apple.mobile.heartbeat"
+    RSD_SERVICE_NAME = "com.apple.mobile.heartbeat.shim.remote"
 
     def __init__(self, lockdown: LockdownServiceProvider):
         self.logger = logging.getLogger(__name__)
@@ -22,7 +24,7 @@ class HeartbeatService:
         else:
             self.service_name = self.RSD_SERVICE_NAME
 
-    def start(self, interval: float = None) -> None:
+    def start(self, interval: Optional[float] = None) -> None:
         start = time.time()
         service = self.lockdown.start_lockdown_service(self.service_name)
 
@@ -30,8 +32,7 @@ class HeartbeatService:
             response = service.recv_plist()
             self.logger.debug(response)
 
-            if interval is not None:
-                if time.time() >= start + interval:
-                    break
+            if interval is not None and time.time() >= start + interval:
+                break
 
-            service.send_plist({'Command': 'Polo'})
+            service.send_plist({"Command": "Polo"})
