@@ -3,7 +3,7 @@ from datetime import datetime
 
 from pymobiledevice3.services.syslog import SyslogService
 
-SYSLOG_TIME_FORMAT = '%b %d %H:%M:%S'
+SYSLOG_TIME_FORMAT = "%b %d %H:%M:%S"
 
 
 def extract_log_time(log_line: str) -> datetime:
@@ -12,8 +12,8 @@ def extract_log_time(log_line: str) -> datetime:
     :param log_line: Line to extract time from.
     :return: Parsed datetime object.
     """
-    timestamp_end = log_line.find(':') + len('MM:SS')
-    return datetime.strptime(log_line[:timestamp_end + 1], SYSLOG_TIME_FORMAT)
+    timestamp_end = log_line.find(":") + len("MM:SS")
+    return datetime.strptime(log_line[: timestamp_end + 1], SYSLOG_TIME_FORMAT)
 
 
 def test_logs_watching_time(lockdown):
